@@ -32,7 +32,7 @@ from threading import Barrier, Condition, Thread
 
 from .multipart import Data
 
-__version__ = "0.9.7"
+__version__ = "0.9.8"
 
 BASE_URL = "https://volafile.io"
 BASE_ROOM_URL = BASE_URL + "/r/"
@@ -394,8 +394,8 @@ class Room:
                                                 file[2],  # type
                                                 file[3],  # size
                                                 file[4] / 1000,  # expire time
-                                                file[5] / 1000,  # upload time
                                                 file[6]['user'])
+                    self.conn.make_call("get_fileinfo", [file[0]])
             elif data_type == "delete_file":
                 del self._files[data]
             elif data_type == "chat":
@@ -421,10 +421,11 @@ class Room:
                 self.user.name = data
             elif data_type == "owner":
                 self.owner = data['owner']
-            elif data_type == "update_assets":
-                # TODO
-                pass
-            elif data_type in ("subscribed", "hooks", "time", "login"):
+            elif data_type == "fileinfo":
+                file = self._files[data['id']]
+                file.info = data.get(file.type)
+            elif data_type in ("update_assets", "subscribed",
+                               "hooks", "time", "login"):
                 pass
             else:
                 warnings.warn(
@@ -604,7 +605,7 @@ class File:
 
     """Basically a struct for a file's info on volafile, with an additional
     method to retrieve the file's URL."""
-    # pylint: disable=too-few-public-methods
+    # pylint: disable=invalid-name
     # pylint: disable=too-many-arguments
 
     def __init__(
@@ -614,21 +615,20 @@ class File:
             file_type=None,
             size=None,
             expire_time=None,
-            upload_time=None,
-            uploader=None
+            uploader=None,
     ):
-        self.file_id = file_id
+        self.id = file_id
         self.name = name
-        self.file_type = file_type
+        self.type = file_type
         self.size = size
         self.expire_time = expire_time
-        self.upload_time = upload_time
         self.uploader = uploader
+        self.info = None
 
     @property
     def url(self):
         """Gets the download url of the file"""
-        return "{}/get/{}/{}".format(BASE_URL, self.file_id, self.name)
+        return "{}/get/{}/{}".format(BASE_URL, self.id, self.name)
 
     @property
     def expired(self):
@@ -640,9 +640,31 @@ class File:
         """Returns how many seconds before this file expires"""
         return self.expire_time - time.time()
 
+    @property
+    def thumbnail(self):
+        """Returns the thumbnail url for this image, audio, or video file."""
+        if self.type not in ("video", "image", "audio"):
+            raise RuntimeError("Only videos, audio and images have thumbnails")
+        vid = "video_" if self.type == "video" else ""
+        return "{}/asset/{}/{}thumb".format(BASE_URL, self.id, vid)
+
+    @property
+    def resolution(self):
+        """Gets the resolution of this image or video file in format (W, H)"""
+        if self.type not in ("video", "image"):
+            raise RuntimeError("Only videos and images have resolutions")
+        return (self.info['width'], self.info['height'])
+
+    @property
+    def duration(self):
+        """Returns the duration in seconds of this audio or video file"""
+        if self.type not in ("video", "audio"):
+            raise RuntimeError("Only videos and audio have durations")
+        return self.info.get('length') or self.info.get('duration')
+
     def __repr__(self):
         return ("<File({},{},{},{})>".
-                format(self.file_id, self.size, self.uploader, self.name))
+                format(self.id, self.size, self.uploader, self.name))
 
 
 class User:
